# Pandan

Pandan is a small library to make decisions from sequences of evidences.

## Installation
Pandan is registered to Python Package Index, and can be installed by:

  ```
  pip install pandan
  ```

## Message Protocol

## License
Chaton uses the [BSD 3-Clause](https://opensource.org/licenses/BSD-3-Clause).

## Contact
Any questions or assistance? Please contact me at minsu(at)etri.re.kr.